@@ -29,8 +29,8 @@ var usage string
 var ErrNoMarkdownFile = errors.New("no xc compatible markdown file found")
 
 type config struct {
-	version, help, short, display, complete, uncomplete bool
-	filename, heading                                   string
+	version, help, short, display, noTTY, complete, uncomplete bool
+	filename, heading                                          string
 }
 
 var version = ""
@@ -70,6 +70,9 @@ func flags() config {
 
 	flag.BoolVar(&cfg.complete, "complete", false, "install shell completion for xc")
 	flag.BoolVar(&cfg.uncomplete, "uncomplete", false, "uninstall shell completion for xc")
+
+	flag.BoolVar(&cfg.noTTY, "no-tty", false, "disable interactive picker")
+
 	flag.Parse()
 	return cfg
 }
@@ -139,6 +142,14 @@ func printTasks(tasks models.Tasks, short bool) {
 	}
 }
 
+func displayAndRunTasks(ctx context.Context, tasks models.Tasks, dir string, cfg config) error {
+	if cfg.noTTY || cfg.short {
+		printTasks(tasks, cfg.short)
+		return nil
+	}
+	return interactivePicker(ctx, tasks, dir)
+}
+
 func printTask(task models.Task, maxLen int) {
 	padLen := maxLen - len(task.Name)
 	pad := strings.Repeat(" ", padLen)
@@ -189,8 +200,7 @@ func runMain() error {
 	tav := flag.Args()
 	// xc
 	if len(tav) == 0 {
-		printTasks(tasks, cfg.short)
-		return nil
+		return displayAndRunTasks(ctx, tasks, dir, cfg)
 	}
 	ta, ok := tasks.Get(tav[0])
 	if !ok {
